function [x,y]=GenerateData(num,classProb,variance)
% generate input data, points in 2D
% two clusters forming crescents

% Input: num = number of data points
%        classProb = membership to clusters (vector of two items)
%        variance = variance inside a cluster

% default parameters
switch(nargin)
  case 0, num=100; classProb=[0.5,0.5]; variance=0.04;
  case 1, classProb=[0.5,0.5]; variance=0.04;
  case 2, variance=0.04;
end

% check of the membership to clusters
if (length(classProb)~=2)
  error('Membership to clusters should not be two.');
end
if(sum(classProb)~=1)
  warning('Sum of probabilities is not 1.');
  if(sum(classProb)~=0)
    classProb=classProb/sum(classProb);
  else
    classProb=[0.5,0.5];
  end
end

% defines the number of examples in clusters
num = floor(num);  % if num is not integer
pos = rand(num,1);
numPtsClasses=zeros(1,2);
numPtsClasses(1)=sum(pos >= 0 & pos<classProb(1));
numPtsClasses(2)=sum(pos >= sum(classProb(1)) & pos<sum(classProb(1:2)));  
  
% Generating data points
y=zeros(num,1);
num_pos=numPtsClasses(1); num_neg=numPtsClasses(2);
radii=ones(num,1);
phi  =rand(num_pos+num_neg,1).*pi;          

% two crescents
x=zeros(num,2);
for i=1:num_pos
  x(i,1)=radii(i)*cos(phi(i));
  x(i,2)=radii(i)*sin(phi(i));
  y(i,1)=1;
end
for i=num_pos+1:num_neg+num_pos
  x(i,1)=1+radii(i)*cos(phi(i));
  x(i,2)=-radii(i)*sin(phi(i))+0.5;
  y(i,1)=2;
end
% add sum 
x=x + sqrt(variance)*randn(num,2);
display(['Number of points in cluster 1: ',num2str(numPtsClasses(1)),'; in cluster 2: ',num2str(numPtsClasses(2))]);
          